@@ -420,7 +420,6 @@ static void
 gtk_source_gutter_dispose (GObject *object)
 {
 	GtkSourceGutter *gutter = (GtkSourceGutter *)object;
-	GtkWidget *child;
 
 	g_clear_pointer (&gutter->target_binding, g_binding_unbind);
 
@@ -430,11 +429,6 @@ gtk_source_gutter_dispose (GObject *object)
 		g_clear_object (&gutter->signals);
 	}
 
-	while ((child = gtk_widget_get_first_child (GTK_WIDGET (gutter))))
-	{
-		gtk_widget_unparent (child);
-	}
-
 	G_OBJECT_CLASS (gtk_source_gutter_parent_class)->dispose (object);
 }
 
@@ -824,14 +818,10 @@ gtk_source_gutter_snapshot (GtkWidget   *widget,
 		}
 	}
 
-	/* Draw the current-line highlight if necessary. Keep this in sync
-         * with gtk_source_view_paint_current_line_highlight().
-         */
+	/* Draw the current-line highlight if necessary */
 	if (gtk_source_view_get_highlight_current_line (gutter->view) &&
-	    (!gtk_text_buffer_get_selection_bounds (buffer, &cur, &sel) ||
-             gtk_text_iter_get_line (&cur) == gtk_text_iter_get_line (&sel)))
+	    !gtk_text_buffer_get_selection_bounds (buffer, &cur, &sel))
 	{
-		GtkRoot *root;
 		GdkRGBA highlight;
 		guint cursor_line;
 
@@ -839,16 +829,13 @@ gtk_source_gutter_snapshot (GtkWidget   *widget,
 
 		if (cursor_line >= gtk_source_gutter_lines_get_first (gutter->lines) &&
 		    cursor_line <= gtk_source_gutter_lines_get_last (gutter->lines) &&
-		    _gtk_source_view_get_current_line_number_background (gutter->view, &highlight) &&
-		    (root = gtk_widget_get_root (GTK_WIDGET (gutter->view))) &&
-		    GTK_IS_WINDOW (root) &&
-		    gtk_window_is_active (GTK_WINDOW (root)))
+		    _gtk_source_view_get_current_line_number_background (gutter->view, &highlight))
 		{
 			int width = gtk_widget_get_width (widget);
-			double height;
-			double y;
+			int height;
+			int y;
 
-			gtk_source_gutter_lines_get_line_extent (gutter->lines,
+			gtk_source_gutter_lines_get_line_yrange (gutter->lines,
 			                                         cursor_line,
 			                                         GTK_SOURCE_GUTTER_RENDERER_ALIGNMENT_MODE_CELL,
 			                                         &y,
@@ -890,7 +877,7 @@ gtk_source_gutter_snapshot (GtkWidget   *widget,
 	gtk_snapshot_push_clip (snapshot,
 	                        &GRAPHENE_RECT_INIT (0,
 	                                             0,
-                                                     clip_width,
+						     clip_width,
 	                                             gtk_widget_get_height (widget)));
 
 	/* Now let the renderers draw the content for each line. Because
@@ -932,14 +919,14 @@ renderer_at_x (GtkSourceGutter *gutter,
 	for (item = gutter->renderers; item; item = g_list_next (item))
 	{
 		Renderer *renderer = item->data;
-		graphene_rect_t grect;
+		GtkAllocation alloc;
 
-		if (gtk_widget_compute_bounds (GTK_WIDGET (renderer->renderer), GTK_WIDGET (gutter), &grect))
+		gtk_widget_get_allocation (GTK_WIDGET (renderer->renderer),
+		                           &alloc);
+
+		if (x >= alloc.x && x <= alloc.x + alloc.width)
 		{
-			if (x >= grect.origin.x && x <= grect.origin.x + grect.size.width)
-			{
-				return renderer;
-			}
+			return renderer;
 		}
 	}
 
@@ -953,32 +940,27 @@ get_renderer_rect (GtkSourceGutter *gutter,
                    gint             line,
                    GdkRectangle    *rectangle)
 {
-	graphene_rect_t grect;
+	gint y;
+	gint ypad;
 
-	if (gtk_widget_compute_bounds (GTK_WIDGET (renderer->renderer), GTK_WIDGET (gutter), &grect))
-	{
-		int ypad;
-		int height;
-		int y;
+	gtk_widget_get_allocation (GTK_WIDGET (renderer->renderer), rectangle);
 
-		gtk_text_view_get_line_yrange (GTK_TEXT_VIEW (gutter->view),
-		                               iter,
-		                               &y,
-		                               &height);
-		gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (gutter->view),
-		                                       gutter->window_type,
-		                                       0,
-		                                       y,
-		                                       NULL,
-		                                       &y);
+	gtk_text_view_get_line_yrange (GTK_TEXT_VIEW (gutter->view),
+	                               iter,
+	                               &y,
+	                               &rectangle->height);
 
-		ypad = gtk_source_gutter_renderer_get_ypad (renderer->renderer);
+	gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (gutter->view),
+	                                       gutter->window_type,
+	                                       0,
+	                                       y,
+	                                       NULL,
+	                                       &rectangle->y);
 
-		rectangle->y = y + ypad;
-		rectangle->x = grect.origin.x;
-		rectangle->height = height - (2 * ypad);
-		rectangle->width = grect.size.width;
-	}
+	ypad = gtk_source_gutter_renderer_get_ypad (renderer->renderer);
+
+	rectangle->y += ypad;
+	rectangle->height -= 2 * ypad;
 }
 
 static gboolean
